@@ -1,6 +1,6 @@
 #!/usr/bin/perl
 #
-# $Header: /Users/claude/fuzz/lib/Genezzo/Row/RCS/RSIdx1.pm,v 6.1 2004/08/12 09:31:15 claude Exp $
+# $Header: /Users/claude/fuzz/lib/Genezzo/Row/RCS/RSIdx1.pm,v 6.2 2004/12/14 07:53:32 claude Exp claude $
 #
 # copyright (c) 2003, 2004 Jeffrey I Cohen, all rights reserved, worldwide
 #
@@ -568,4 +568,7 @@ Copyright (c) 2003, 2004 Jeffrey I Cohen.  All rights reserved.
 
 Address bug reports and comments to: jcohen@genezzo.com
 
+For more information, please visit the Genezzo homepage 
+at http://www.genezzo.com
+
 =cut
